@@ -653,7 +653,13 @@ def ortholog(args):
         help="Distance to extend from liftover. Defaults to half of --dist",
     )
     p.set_cpus()
-    p.set_dotplot_opts()
+    dotplot_group = p.set_dotplot_opts()
+    dotplot_group.add_option(
+        "--notex", default=False, action="store_true", help="Do not use tex"
+    )
+    dotplot_group.add_option(
+        "--no_dotplot", default=False, action="store_true", help="Do not make dotplot"
+    )
 
     opts, args = p.parse_args(args)
 
@@ -715,7 +721,7 @@ def ortholog(args):
             scan(dargs)
         if quota:
             quota_main([lifted_anchors, "--quota={0}".format(quota), "--screen"])
-        if need_update(anchors, pdf):
+        if need_update(anchors, pdf) and not opts.no_dotplot:
             from jcvi.graphics.dotplot import dotplot_main
 
             dargs = [anchors]
@@ -729,6 +735,8 @@ def ortholog(args):
                 dargs += ["--genomenames", opts.genomenames]
             if opts.theme:
                 dargs += ["--theme", opts.theme]
+            if opts.notex:
+                dargs += ["--notex"]
             dotplot_main(dargs)
         return
 
