@@ -28,10 +28,13 @@ from jcvi.utils.range import range_intersect
 from jcvi.apps.base import OptionParser, OptionGroup, ActionDispatcher, need_update
 
 
+Supported_AGP_Version = "2.1"
+AGP_Version_Pragma = "##agp-version " + Supported_AGP_Version
 Valid_component_type = list("ADFGNOPUW")
 
 Valid_gap_type = (
-    "fragment",
+    "scaffold",
+    "fragment",  # in v2.0, obsolete in v2.1
     "clone",  # in v1.1, obsolete in v2.0
     "contig",
     "centromere",
@@ -39,7 +42,7 @@ Valid_gap_type = (
     "heterochromatin",
     "telomere",
     "repeat",  # in both versions
-    "scaffold",
+    "contamination",
 )  # new in v2.0
 
 Valid_orientation = ("+", "-", "0", "?", "na")
@@ -54,6 +57,8 @@ Valid_evidence = (
     "within_clone",
     "clone_contig",
     "map",
+    "pcr",  # new in v2.1
+    "proximity_ligation",  # new in v2.1
     "strobe",
     "unspecified",
 )
@@ -235,6 +240,12 @@ class AGPLine(object):
                 self.object_span,
                 self.gap_length,
             )
+            assert (
+                self.gap_type in Valid_gap_type
+            ), "gap_type must be one of {}, you have {}".format(
+                "|".join(Valid_gap_type), self.gap_type
+            )
+
             assert all(
                 x in Valid_evidence for x in self.linkage_evidence
             ), "linkage_evidence must be one of {0}, you have {1}".format(
@@ -349,6 +360,7 @@ class AGP(LineFile):
     def print_header(
         cls, fw=sys.stdout, organism=None, taxid=None, source=None, comment=None
     ):
+        print(AGP_Version_Pragma, file=fw)
         # these comments are entirely optional, modeled after maize AGP
         if organism:
             print("# ORGANISM: {0}".format(organism), file=fw)
@@ -1138,6 +1150,7 @@ def frombed(args):
         type="int",
         help="Insert gaps of size",
     )
+    p.add_option("--evidence", default="map", help="Linkage evidence to add in AGP")
     opts, args = p.parse_args(args)
 
     if len(args) != 1:
@@ -1165,7 +1178,7 @@ def frombed(args):
                             gapsize,
                             "scaffold",
                             "yes",
-                            "map",
+                            opts.evidence,
                         )
                     ),
                     file=fw,
